rareGE-package:
Testing Gene-Environment Interaction for Rare Genetic Variants
Description
Tests gene-environment interaction for rare genetic variants using Sequence Kernel Association Test (SKAT) type gene-based tests. Includes two tests for the interaction term only, and one joint test for genetic main effects and gene-environment interaction.
Details
|
Package: |
| rareGE |
|
Type: |
| Package |
|
Version: |
| 0.1 |
|
Date: |
| 2014-07-28 |
|
License: |
| GPL-3 |
References
Chen H, Meigs JB, Dupuis J. (2014) Incorporating gene-environment interaction in testing for association with rare genetic variants. Hum Hered 78, 81-90.